function [ER p] = choke(Q_l, Q_g, w, p)
    %% Parameters 
    C_unit = 1000*3600*24*365; % Conversion factor [m/s] to [mm/year]
    C1 = 1.25; % Geometry factor [-]
    K = 2e-9; % Material erosion constant [(m/s)^-n]
    rho_t = 7800; % Densiy carbon steel [kg/m3]
    n = 2.6; % [-]
    GF = 2; % Geometry factor
    A_g = 2*p.choke.H*p.choke.D; % Effective gallery area [m2]
    m_p = w*p.rho.p; % Mass rate of sand [kg/s] 
    D = p.D1*2.54/100; % Diameter from [inches] to [m]
    
    %% Calculate mixing properties
    A2 = (pi*D^2)/4; % Pipe cross sectional area [m2]
    V.sl = Q_l/A2; % Superficial liquid velocity [m/s]
    V.sg = Q_g/A2; % Superficial gas velocity [m/s]
    rho.m = (p.rho.l*V.sl + p.rho.g*V.sg)/(V.sl+V.sg); % Mixture density [kg/m3]
    mu.m = (p.mu.l*V.sl + p.mu.g*V.sg)/(V.sl+V.sg); % Mixture viscosity [kg/ms]
    
    Q.m = Q_l + Q_g; % Mixed volumetric flow
    V.m = 0.75*Q.m/A_g; % Particle impact velocity
    
    %% Calculate characteristic impact angle 
    alpha = atan(1/sqrt(2*p.choke.r)); % Particle impact angle [rad]
    F = @(alpha) 0.6*(sin(alpha)+7.2* (sin(alpha)-(sin(alpha))^2)^0.6*(1-exp(-20*alpha)));
    
    %% Calculate dimensionless parameters A and beta
    A = rho.m^2*tan(alpha)*V.m*p.D1/(p.rho.p*mu.m); % [-]
    beta = p.rho.p/rho.m; % [-]
    
    %% Calculate the particle size correction function
    gamma_c = 1/(beta*(1.88*log(A)-6.04));
   
    if gamma_c > 0.1
        gamma_c = 0.1;
    end
    
    gamma = p.d_p/p.D1;
    
    if gamma < gamma_c
        G = gamma/gamma_c;
    else
        G = 1;
    end
    
    %% Calculate erosion rate
    ER = K*F(alpha)*V.m^n*G*C1*GF*m_p*C_unit/(rho_t*A_g); % Erosion rate [mm/year]
end